import { ValidatedMethod } from "../lib/validated-method.js";

export const getTabInfo = new ValidatedMethod({
  name: "getTabInfo",
  run: ({ tabId }, { blocker, guardian }) => {
    try {
      return blocker.getTabInfo(false, tabId);
    } catch (err) {
      guardian.setLastError(err);
    }
  },
});

export const pause = new ValidatedMethod({
  name: "pause",
  run: (_, { blocker, guardian }) => {
    try {
      return blocker.isPaused(true);
    } catch (err) {
      guardian.setLastError(err);
    }
  },
});

export const resume = new ValidatedMethod({
  name: "resume",
  run: (_, { blocker, guardian }) => {
    try {
      return blocker.isPaused(false);
    } catch (err) {
      guardian.setLastError(err);
    }
  },
});

export const allow = new ValidatedMethod({
  name: "allow",
  run: ({ url, origin }, { blocker, guardian }) => {
    try {
      return blocker.createDomainAllowListFilter(url, origin);
    } catch (err) {
      guardian.setLastError(err);
    }
  },
});

export const clear = new ValidatedMethod({
  name: "clear",
  run: ({ url, tabId }, { blocker, guardian }) => {
    try {
      return blocker.tryToRemoveAllowList(url, tabId);
    } catch (err) {
      guardian.setLastError(err);
    }
  },
});
